// src/ApiStage.ts
import { Enum } from "@xylabs/enum";
var ApiStage = Enum({
  Beta: "beta",
  Local: "local",
  Prod: "prod"
});

// src/ApiClient.ts
var ApiClient = class {
  constructor(token, stage) {
    this.token = token;
    this.stage = stage;
    this.stage = stage ?? ApiStage.Prod;
    this.token = token;
  }
};

// src/ApiEndpoint.ts
import { isUndefined } from "@xylabs/typeof";
import axios from "axios";
var ApiEndpoint = class {
  _value;
  config;
  path;
  constructor(config, path) {
    this.config = config;
    this.path = path;
  }
  get value() {
    return this._value;
  }
  get headers() {
    return isUndefined(this.config.jwtToken) ? void 0 : { Authorization: this.config.jwtToken };
  }
  get url() {
    return `${this.config.apiDomain}/${this.path}`;
  }
  async fetch() {
    const response = await axios.get(this.url, { headers: this.headers });
    if (response.status === 200) {
      this._value = response.data;
    } else {
      throw new Error("Unexpected Status Code");
    }
    return this._value;
  }
  async get() {
    return this._value ?? await this.fetch();
  }
  async insert(value) {
    const response = await axios.post(this.url, value, { headers: this.headers });
    if (response.status === 200) {
      this._value = response.data;
    } else {
      throw new Error("Unexpected Status Code");
    }
    return this._value;
  }
};

// src/getApiStage.ts
var getApiStage = (hostname) => {
  if (hostname.startsWith("localhost")) {
    return ApiStage.Local;
  } else if (hostname.startsWith("beta.")) {
    return ApiStage.Beta;
  } else {
    return ApiStage.Prod;
  }
};
export {
  ApiClient,
  ApiEndpoint,
  ApiStage,
  getApiStage
};
//# sourceMappingURL=index.mjs.map